spannertools.MeasuredComplexBeamSpanner
=======================================

.. autoclass:: abjad.tools.spannertools.MeasuredComplexBeamSpanner
   :members:
   :undoc-members:
   :show-inheritance:
